==> CoinBinary-CoinAll-1.4.0.zip: CoinAll-1.4.0/Couenne/src/branch/CouenneOrbitBranchingObj.cpp <==
/* $Id: CouenneOrbitBranchingObj.cpp 258 2009-09-05 15:54:35Z pbelotti $
 *
 * Name:    CouenneOrbitBranchingObj.cpp
 * Authors: Jim Ostrowski, University of Waterloo
 *          Pietro Belotti, Lehigh University
 *          
 * Purpose: Branching object for auxiliary variables
 *
 * This file is licensed under the Common Public License (CPL)
 */

#include "CoinHelperFunctions.hpp"

#include "OsiRowCut.hpp"

#include "CouenneProblem.hpp"
#include "CouenneObject.hpp"
#include "CouenneOrbitBranchingObj.hpp"
#include "CouenneCutGenerator.hpp"

class CouenneCutGenerator;

// translate changed bound sparse array into a dense one
void sparse2dense (int ncols, t_chg_bounds *chg_bds, int *&changed, int &nchanged);


/** \brief Constructor. 
 *
 * Get a variable as an argument and set value_ through a call to
 * operator () of that exprAux.
*/

CouenneOrbitBranchingObj::CouenneOrbitBranchingObj (OsiSolverInterface *solver,
						    const OsiObject * originalObject,
						    JnlstPtr jnlst, 
						    CouenneCutGenerator *cutGen,
						    CouenneProblem *problem,
						    expression *var, 
						    int way, 
						    CouNumber brpoint, 
						    bool doFBBT, bool doConvCuts):

  CouenneBranchingObject (solver, originalObject, jnlst, cutGen, problem, 
			  var, way, brpoint, doFBBT, doConvCuts) {}



/** \brief Execute the actions required to branch, as specified by the
 *	   current state of the branching object, and advance the
 *         object's state.
 *
 *         Returns change in guessed objective on next branch
 */

double CouenneOrbitBranchingObj::branch (OsiSolverInterface * solver) {

  return 0;
}

==> CoinBinary-CoinAll-1.6.1.zip: CoinAll-1.6.1/Couenne/src/branch/CouenneOrbitBranchingObj.cpp <==
/* $Id: CouenneOrbitBranchingObj.cpp 506 2011-02-15 14:36:48Z stefan $
 *
 * Name:    CouenneOrbitBranchingObj.cpp
 * Authors: Jim Ostrowski, University of Waterloo
 *          Pietro Belotti, Lehigh University
 *          
 * Purpose: Branching object for auxiliary variables
 *
 * This file is licensed under the Eclipse Public License (EPL)
 */

#include "CoinHelperFunctions.hpp"

#include "OsiRowCut.hpp"

#include "CouenneCutGenerator.hpp"
#include "CouenneProblem.hpp"
#include "CouenneObject.hpp"
#include "CouenneOrbitBranchingObj.hpp"

using namespace Couenne;

namespace Couenne {
class CouenneCutGenerator;
}

// translate changed bound sparse array into a dense one
void sparse2dense (int ncols, t_chg_bounds *chg_bds, int *&changed, int &nchanged);


/** \brief Constructor. 
 *
 * Get a variable as an argument and set value_ through a call to
 * operator () of that exprAux.
*/

CouenneOrbitBranchingObj::CouenneOrbitBranchingObj (OsiSolverInterface *solver,
						    const OsiObject * originalObject,
						    JnlstPtr jnlst, 
						    CouenneCutGenerator *cutGen,
						    CouenneProblem *problem,
						    expression *var, 
						    int way, 
						    CouNumber brpoint, 
						    bool doFBBT, bool doConvCuts):

  CouenneBranchingObject (solver, originalObject, jnlst, cutGen, problem, 
			  var, way, brpoint, doFBBT, doConvCuts) {


}



/** \brief Execute the actions required to branch, as specified by the
 *	   current state of the branching object, and advance the
 *         object's state.
 *
 *         Returns change in guessed objective on next branch
 */

double CouenneOrbitBranchingObj::branch (OsiSolverInterface * solver) {

  return 0;
}
